| activation_leaky_relu | R Documentation |
Creates a leaky rectified linear unit activation function object.
activation_leaky_relu(alpha = 0.01)
alpha |
A non-negative numeric value controlling the slope for negative inputs. |
An object of class "met_activation".
act <- activation_leaky_relu(alpha = 0.01)
act$fn(c(-1, 0, 1))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.