| as_metrics | R Documentation |
Converts a character vector or a list of metric objects into a list of metric objects.
as_metrics(metrics)
metrics |
A character vector, a single metric object, or a list of metric objects. |
A list of objects of class "met_metric".
as_metrics(c("rmse", "mae", "r2"))
as_metrics(list(metric_accuracy(), metric_f1()))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.