| optimizer_abc | R Documentation |
Creates an Artificial Bee Colony optimizer object for continuous optimization problems.
optimizer_abc(colony_size = 30, max_iter = 100, limit = NULL)
colony_size |
Total colony size. Half of the colony is used as employed bees and half as onlooker bees. |
max_iter |
Maximum number of iterations. |
limit |
Number of unsuccessful trials before a food source is abandoned. |
An object of class "met_optimizer".
Karaboga, D., and Basturk, B. (2007). A Powerful and Efficient Algorithm for Numerical Function Optimization: Artificial Bee Colony (ABC) Algorithm. Journal of Global Optimization, 39, 459–471. doi:10.1007/s10898-007-9149-x
Karaboga, D., and Ozturk, C. (2009). Neural Networks Training by Artificial Bee Colony Algorithm on Pattern Classification. Neural Network World, 19(3), 279–292.
optimizer_abc()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.