| optimizer_gwo | R Documentation |
Creates a Grey Wolf Optimizer object for continuous optimization problems.
optimizer_gwo(pop_size = 30, max_iter = 100, a_start = 2, a_end = 0)
pop_size |
Population size. |
max_iter |
Maximum number of iterations. |
a_start |
Initial value of the control parameter |
a_end |
Final value of the control parameter |
An object of class "met_optimizer".
Mirjalili, S., Mirjalili, S. M., and Lewis, A. (2014). Grey Wolf Optimizer. Advances in Engineering Software, 69, 46–61. doi:10.1016/j.advengsoft.2013.12.007
Mirjalili, S. (2015). How Effective is the Grey Wolf Optimizer in Training Multi-Layer Perceptrons. Applied Intelligence, 43, 150–161. doi:10.1007/s10489-014-0645-7
optimizer_gwo()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.