predict.metann: Predict with a metANN Model

View source: R/metann.R

predict.metannR Documentation

Predict with a metANN Model

Description

Generates predictions from a fitted metANN model.

Usage

## S3 method for class 'metann'
predict(
  object,
  newdata,
  type = c("response", "prob", "class"),
  threshold = 0.5,
  ...
)

Arguments

object

A fitted object of class "metann".

newdata

New data used for prediction. For formula-based models, this should be a data frame. For x-y models, this should be a numeric matrix or numeric data frame.

type

Prediction type. For regression models, "response" returns numeric predictions. For classification models, "class" returns predicted class labels, "prob" returns predicted probabilities, and "response" returns the default response, which is class labels.

threshold

Classification threshold for binary classification.

...

Additional arguments.

Value

A numeric vector, matrix, or factor depending on the task and prediction type.


metANN documentation built on May 16, 2026, 1:06 a.m.