| count_parameters | R Documentation |
Computes the total number of weights and bias terms required by a multilayer perceptron architecture.
count_parameters(architecture, input_dim = NULL)
architecture |
An object created by |
input_dim |
Optional positive integer specifying the number of input
features. If |
A positive integer giving the total number of parameters.
arch <- mlp_architecture(
input_dim = 4,
layers = list(
dense_layer(5, activation = "relu"),
dense_layer(1, activation = "linear")
)
)
count_parameters(arch)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.