| dense_layer | R Documentation |
Creates a fully connected dense layer object for use in metANN architectures.
dense_layer(
units,
activation = "relu",
use_bias = TRUE,
trainable = TRUE,
name = NULL
)
units |
A positive integer specifying the number of neurons in the layer. |
activation |
A character string or a |
use_bias |
Logical. Whether to include a bias term in the layer. |
trainable |
Logical. Whether the layer parameters should be trainable. |
name |
An optional character string specifying the layer name. |
An object of class "met_dense_layer".
dense_layer(10, activation = "relu")
dense_layer(1, activation = activation_linear())
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.