| evaluate | R Documentation |
Evaluates a fitted metANN model on new data.
evaluate(object, newdata, y_true = NULL, metrics = NULL, threshold = 0.5, ...)
object |
A fitted object of class |
newdata |
New data used for evaluation. For formula-based models, this should be a data frame containing the response variable. For x-y models, this should be a numeric matrix or numeric data frame. |
y_true |
Optional true response values. Required for x-y models. For
formula-based models, if |
metrics |
Optional performance metrics. If |
threshold |
Classification threshold for binary classification. |
... |
Additional arguments passed to |
An object of class "metann_evaluation".
fit <- met_mlp(
formula = Petal.Width ~ Sepal.Length + Sepal.Width + Petal.Length,
data = iris,
hidden_layers = c(5),
optimizer = optimizer_pso(pop_size = 10, max_iter = 10),
seed = 123,
verbose = FALSE
)
evaluate(fit, newdata = iris)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.