| loss_binary_crossentropy | R Documentation |
Creates a binary cross-entropy loss function object.
loss_binary_crossentropy(epsilon = 1e-15)
epsilon |
A small positive numeric value used for numerical stability. |
An object of class "met_loss".
Bridle, J. S. (1990). Probabilistic Interpretation of Feedforward Classification Network Outputs, with Relationships to Statistical Pattern Recognition. In Neurocomputing: Algorithms, Architectures and Applications, 227–236. Springer.
loss <- loss_binary_crossentropy()
loss$fn(c(0, 1, 1), c(0.1, 0.8, 0.9))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.