| mlp_architecture | R Documentation |
Creates a multilayer perceptron architecture object from a list of dense layers.
mlp_architecture(layers, input_dim = NULL, name = "mlp")
layers |
A list of dense layer objects created by |
input_dim |
Optional positive integer specifying the number of input
features. This can be left as |
name |
Optional character string specifying the architecture name. |
An object of class "met_mlp_architecture".
architecture <- mlp_architecture(
layers = list(
dense_layer(10, activation = "relu"),
dense_layer(1, activation = "linear")
)
)
architecture
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.