| predict.metann | R Documentation |
Generates predictions from a fitted metANN model.
## S3 method for class 'metann'
predict(
object,
newdata,
type = c("response", "prob", "class"),
threshold = 0.5,
...
)
object |
A fitted object of class |
newdata |
New data used for prediction. For formula-based models, this should be a data frame. For x-y models, this should be a numeric matrix or numeric data frame. |
type |
Prediction type. For regression models, |
threshold |
Classification threshold for binary classification. |
... |
Additional arguments. |
A numeric vector, matrix, or factor depending on the task and prediction type.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.